@@ -27,6 +27,14 @@ runtime371="3.7.1"
 docker push ${user}/${image}:${runtime371}
 docker push ${user}/${image}:${runtime371}-dev
 
+runtime37="3.7"
+docker push ${user}/${image}:${runtime37}
+docker push ${user}/${image}:${runtime37}-dev
+
 runtime385="3.8.5"
 docker push ${user}/${image}:${runtime385}
 docker push ${user}/${image}:${runtime385}-dev
+
+runtime38="3.8"
+docker push ${user}/${image}:${runtime38}
+docker push ${user}/${image}:${runtime38}-dev
